@@ -108,7 +108,15 @@ gar_auth <- function(token = NULL,
 
   } else if(is.string(token)){ ## a filepath
     
-    google_token <- read_cache_token(token_path = token)
+    if(file.exists(token)){
+      google_token <- read_cache_token(token_path = token)
+    } else {
+      myMessage("No httr_oauth_cache file found at ", token, " - creating new file.", level = 3)
+      options("googleAuthR.httr_oauth_cache" = token)
+      Authentication$set("public", "token", NULL, overwrite=TRUE)
+      return(gar_auth(token = NULL))
+    }
+
 
   } else {
     stop("Unrecognised token object - class ", class(token), call. = FALSE)
@@ -150,7 +158,7 @@ make_new_token <- function(){
 
   check_existing <- gar_check_existing_token()
   if(!check_existing){
-    myMessage("No auto-refresh of token due to differing options, manual re-authentication required", level = 3)
+    myMessage("Auto-refresh of token not possible, manual re-authentication required", level = 2)
     if(!interactive()){
       stop("Authentication options didn't match existing session token and not interactive session
            so unable to manually reauthenticate", call. = FALSE)
@@ -259,11 +267,12 @@ read_cache_token <- function(token_path){
   
   myMessage("Reading token from file path", level = 2)
   
-  google_token <- tryCatch({suppressWarnings(readRDS(token_path))},
+  google_token <- tryCatch({readRDS(token_path)},
                            error = function(ex){
-                             warning(sprintf("Cannot read token from alleged .rds file:\n%s",
-                                             token_path))
-                             stop(ex)
+                             stop(sprintf("Cannot read token from alleged .rds file:\n%s",
+                                             token_path), 
+                                  ex, 
+                                  call. = FALSE)
                            })
   
   if(is.list(google_token)){
@@ -275,8 +284,9 @@ read_cache_token <- function(token_path){
     stop("Unknown object read from ", token_path, " of class ", class(google_token))
   }
   
-  options("googleAuthR.httr_oauth_cache" = token_path)
-  google_token$cache_path <- token_path
+  ## for existing tokens, set the options to what is in the token
+  google_token <- overwrite_options(google_token, token_path = token_path)
+  
   Authentication$set("public", "method", "filepath", overwrite=TRUE)
   ## set the global session token
   Authentication$set("public", "token", google_token, overwrite=TRUE)
@@ -284,6 +294,34 @@ read_cache_token <- function(token_path){
   google_token
 }
 
+overwrite_options <- function(google_token, token_path){
+  options("googleAuthR.httr_oauth_cache" = token_path)
+  google_token$cache_path <- token_path
+  
+  if(is.different(google_token$params$scope, "googleAuthR.scopes.selected")){
+    myMessage("Setting googleAuthR.scopes.selected to ", paste(google_token$params$scope, collapse = " "), level = 3)
+    options("googleAuthR.scopes.selected" = google_token$params$scope)
+  }
+  
+  if(is.null(google_token$app)){
+    myMessage("No client_id in token, authentication from JSON key file", level = 3)
+    return(google_token)
+  }
+  
+  if(is.different(google_token$app$key, "googleAuthR.client_id")){
+    myMessage("Setting googleAuthR.client_id to ", google_token$app$key, level = 3)
+    options("googleAuthR.client_id" = google_token$app$key)
+  }
+  
+  if(is.different(google_token$app$secret, "googleAuthR.client_secret")){
+    myMessage("Setting googleAuthR.client_secret to ", google_token$app$secret, level = 3)
+    options("googleAuthR.client_secret" = google_token$app$secret)
+  }
+
+  google_token
+ 
+}
+
 is.token2.0 <- function(x){
   inherits(x, "Token2.0")
 }
